from tendenci.apps.perms.managers import TendenciBaseManager

class DiscountManager(TendenciBaseManager):
    """
    Model Manager
    """
    pass
